module.exports = defineTest({
	description: 'throw statement is a side effect',
	options: { output: { name: 'myBundle' } }
});
